==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/LineOrthogonal/ts/LineOrthogonal_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LineOrthogonal</name>
    <message>
        <location filename="../LineOrthogonal.ui" line="+17"/>
        <source>Length:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość cięciwy:
Wprowadź długość:</translatorcomment>
        <translation type="unfinished">Długość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Reference Point:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../LineOrthogonalInit.js" line="+2"/>
        <source>&amp;Orthogonal</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Prostopadła
Ograniczaj &amp;prostopadle</translatorcomment>
        <translation type="unfinished">&amp;Prostopadła</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line orthogonal to base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Rysowanie linii prostopadłych do jednostki bazowej</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/LineOrthogonal/ts/LineOrthogonal_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineOrthogonal</name>
    <message>
        <location filename="../LineOrthogonal.ui" line="+17"/>
        <source>Length:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź długość cięciwy:
Wprowadź długość:</translatorcomment>
        <translation>Długość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>&amp;Reference Point:</source>
        <translation>Punkt &amp;odniesienia:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translation>Początek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translation>Koniec</translation>
    </message>
    <message>
        <location filename="../LineOrthogonalInit.js" line="+2"/>
        <source>&amp;Orthogonal</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Prostopadła
Ograniczaj &amp;prostopadle</translatorcomment>
        <translation>&amp;Prostopadła</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line orthogonal to base entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje linie prostopadłe do obiektu</translation>
    </message>
</context>
</TS>
